@@ -16,7 +16,6 @@
 
 #include "secret-collection.h"
 #include "secret-dbus-generated.h"
-#include "secret-enum-types.h"
 #include "secret-item.h"
 #include "secret-paths.h"
 #include "secret-private.h"
@@ -24,6 +23,8 @@
 #include "secret-types.h"
 #include "secret-value.h"
 
+#include "libsecret/secret-enum-types.h"
+
 #include <glib/gi18n-lib.h>
 
 /**
@@ -50,10 +51,7 @@
  *
  * Items can be created with secret_item_create() or secret_service_store().
  *
- * These functions have an unstable API and may change across versions. Use
- * <literal>libsecret-unstable</literal> package to access them.
- *
- * Stability: Unstable
+ * Stability: Stable
  */
 
 /**
@@ -100,11 +98,11 @@ struct _SecretItemPrivate {
 	/* No changes between construct and finalize */
 	SecretService *service;
 	SecretItemFlags init_flags;
-	GCancellable *cancellable;
 
 	/* Locked by mutex */
 	GMutex mutex;
 	SecretValue *value;
+	gint disposed;
 };
 
 static GInitableIface *secret_item_initable_parent_iface = NULL;
@@ -124,7 +122,6 @@ static void
 secret_item_init (SecretItem *self)
 {
 	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, SECRET_TYPE_ITEM, SecretItemPrivate);
-	self->pv->cancellable = g_cancellable_new ();
 	g_mutex_init (&self->pv->mutex);
 }
 
@@ -136,10 +133,12 @@ on_set_attributes (GObject *source,
 	SecretItem *self = SECRET_ITEM (user_data);
 	GError *error = NULL;
 
-	secret_item_set_attributes_finish (self, result, &error);
-	if (error != NULL) {
-		g_warning ("couldn't set SecretItem Attributes: %s", error->message);
-		g_error_free (error);
+	if (!g_atomic_int_get (&self->pv->disposed)) {
+		secret_item_set_attributes_finish (self, result, &error);
+		if (error != NULL) {
+			g_warning ("couldn't set SecretItem Attributes: %s", error->message);
+			g_error_free (error);
+		}
 	}
 
 	g_object_unref (self);
@@ -153,10 +152,12 @@ on_set_label (GObject *source,
 	SecretItem *self = SECRET_ITEM (user_data);
 	GError *error = NULL;
 
-	secret_item_set_label_finish (self, result, &error);
-	if (error != NULL) {
-		g_warning ("couldn't set SecretItem Label: %s", error->message);
-		g_error_free (error);
+	if (!g_atomic_int_get (&self->pv->disposed)) {
+		secret_item_set_label_finish (self, result, &error);
+		if (error != NULL) {
+			g_warning ("couldn't set SecretItem Label: %s", error->message);
+			g_error_free (error);
+		}
 	}
 
 	g_object_unref (self);
@@ -197,12 +198,12 @@ secret_item_set_property (GObject *obj,
 		break;
 	case PROP_ATTRIBUTES:
 		secret_item_set_attributes (self, NULL, g_value_get_boxed (value),
-		                            self->pv->cancellable, on_set_attributes,
+		                            NULL, on_set_attributes,
 		                            g_object_ref (self));
 		break;
 	case PROP_LABEL:
 		secret_item_set_label (self, g_value_get_string (value),
-		                       self->pv->cancellable, on_set_label,
+		                       NULL, on_set_label,
 		                       g_object_ref (self));
 		break;
 	default:
@@ -252,7 +253,7 @@ secret_item_dispose (GObject *obj)
 {
 	SecretItem *self = SECRET_ITEM (obj);
 
-	g_cancellable_cancel (self->pv->cancellable);
+	g_atomic_int_inc (&self->pv->disposed);
 
 	G_OBJECT_CLASS (secret_item_parent_class)->dispose (obj);
 }
@@ -266,7 +267,6 @@ secret_item_finalize (GObject *obj)
 		g_object_remove_weak_pointer (G_OBJECT (self->pv->service),
 		                              (gpointer *)&self->pv->service);
 
-	g_object_unref (self->pv->cancellable);
 	g_mutex_clear (&self->pv->mutex);
 
 	G_OBJECT_CLASS (secret_item_parent_class)->finalize (obj);
@@ -346,13 +346,10 @@ secret_item_class_init (SecretItemClass *klass)
 	                                 G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 
 	/**
-	 * SecretItem:attributes:
+	 * SecretItem:attributes: (type GLib.HashTable(utf8,utf8)) (transfer full)
 	 *
 	 * The attributes set on this item. Attributes are used to locate an
 	 * item. They are not guaranteed to be stored or transferred securely.
-	 *
-	 * Type: GLib.HashTable(utf8,utf8)
-	 * Transfer: full
 	 */
 	g_object_class_install_property (gobject_class, PROP_ATTRIBUTES,
 	             g_param_spec_boxed ("attributes", "Attributes", "Item attributes",
@@ -1173,6 +1170,7 @@ on_item_load_secret (GObject *source,
 	}
 
 	g_simple_async_result_complete (res);
+	g_object_unref (self);
 	g_object_unref (res);
 }
 
@@ -1335,6 +1333,7 @@ loads_closure_free (gpointer data)
 	if (loads->service)
 		g_object_unref (loads->service);
 	g_clear_object (&loads->cancellable);
+	g_hash_table_destroy (loads->items);
 	g_slice_free (LoadsClosure, loads);
 }
 
@@ -1405,7 +1404,7 @@ on_loads_secrets_session (GObject *source,
 
 /**
  * secret_item_load_secrets:
- * @items: (element-type SecretUnstable.Item): the items to retrieve secrets for
+ * @items: (element-type Secret.Item): the items to retrieve secrets for
  * @cancellable: optional cancellation object
  * @callback: called when the operation completes
  * @user_data: data to pass to the callback
@@ -1504,7 +1503,7 @@ secret_item_load_secrets_finish (GAsyncResult *result,
 
 /**
  * secret_item_load_secrets_sync:
- * @items: (element-type SecretUnstable.Item): the items to retrieve secrets for
+ * @items: (element-type Secret.Item): the items to retrieve secrets for
  * @cancellable: optional cancellation object
  * @error: location to place an error on failure
  *
