@@ -36,14 +36,11 @@
  * service using the DBus API directly, and only wish to use a few calls
  * in libsecret.
  *
- * These functions have an unstable API and may change across versions. Use
- * <literal>libsecret-unstable</literal> package to access them.
- *
  * Stability: Unstable
  */
 
 /**
- * secret_collection_new_for_dbus_path:
+ * secret_collection_new_for_dbus_path: (skip)
  * @service: (allow-none): a secret service object
  * @collection_path: the D-Bus path of the collection
  * @flags: options for the collection initialization
@@ -57,6 +54,8 @@
  * the default #SecretService proxy.
  *
  * This method will return immediately and complete asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_collection_new_for_dbus_path (SecretService *service,
@@ -88,7 +87,7 @@ secret_collection_new_for_dbus_path (SecretService *service,
 }
 
 /**
- * secret_collection_new_for_dbus_path_finish:
+ * secret_collection_new_for_dbus_path_finish: (skip)
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
  *
@@ -120,7 +119,7 @@ secret_collection_new_for_dbus_path_finish (GAsyncResult *result,
 }
 
 /**
- * secret_collection_new_for_dbus_path_sync:
+ * secret_collection_new_for_dbus_path_sync: (skip)
  * @service: (allow-none): a secret service object
  * @collection_path: the D-Bus path of the collection
  * @flags: options for the collection initialization
@@ -135,6 +134,8 @@ secret_collection_new_for_dbus_path_finish (GAsyncResult *result,
  * This method may block indefinitely and should not be used in user interface
  * threads.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): the new collection, which should be unreferenced
  *          with g_object_unref()
  */
@@ -168,7 +169,7 @@ secret_collection_new_for_dbus_path_sync (SecretService *service,
 }
 
 /**
- * secret_item_new_for_dbus_path:
+ * secret_item_new_for_dbus_path: (skip)
  * @service: (allow-none): a secret service object
  * @item_path: the D-Bus path of the collection
  * @flags: initialization flags for the new item
@@ -182,6 +183,8 @@ secret_collection_new_for_dbus_path_sync (SecretService *service,
  * the default #SecretService proxy.
  *
  * This method will return immediately and complete asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_item_new_for_dbus_path (SecretService *service,
@@ -213,13 +216,15 @@ secret_item_new_for_dbus_path (SecretService *service,
 }
 
 /**
- * secret_item_new_for_dbus_path_finish:
+ * secret_item_new_for_dbus_path_finish: (skip)
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
  *
  * Finish asynchronous operation to get a new item proxy for an secret
  * item in the secret service.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): the new item, which should be unreferenced
  *          with g_object_unref()
  */
@@ -242,7 +247,7 @@ secret_item_new_for_dbus_path_finish (GAsyncResult *result,
 }
 
 /**
- * secret_item_new_dbus_path_sync:
+ * secret_item_new_for_dbus_path_sync: (skip)
  * @service: (allow-none): a secret service object
  * @item_path: the D-Bus path of the item
  * @flags: initialization flags for the new item
@@ -257,6 +262,8 @@ secret_item_new_for_dbus_path_finish (GAsyncResult *result,
  * This method may block indefinitely and should not be used in user interface
  * threads.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): the new item, which should be unreferenced
  *          with g_object_unref()
  */
@@ -311,7 +318,7 @@ on_search_items_complete (GObject *source,
 }
 
 /**
- * secret_collection_search_for_dbus_paths:
+ * secret_collection_search_for_dbus_paths: (skip)
  * @collection: the secret collection
  * @schema: (allow-none): the schema for the attributes
  * @attributes: (element-type utf8 utf8): search for items matching these attributes
@@ -329,6 +336,8 @@ on_search_items_complete (GObject *source,
  * to get the results of this function. Only the DBus object paths of the
  * items will be returned. If you would like #SecretItem objects to be returned
  * instead, then use the secret_collection_search() function.
+ *
+ * Stability: Unstable
  */
 void
 secret_collection_search_for_dbus_paths (SecretCollection *collection,
@@ -364,7 +373,7 @@ secret_collection_search_for_dbus_paths (SecretCollection *collection,
 }
 
 /**
- * secret_collection_search_for_dbus_paths_finish:
+ * secret_collection_search_for_dbus_paths_finish: (skip)
  * @collection: the secret collection
  * @result: asynchronous result passed to callback
  * @error: location to place error on failure
@@ -375,6 +384,8 @@ secret_collection_search_for_dbus_paths (SecretCollection *collection,
  * #SecretItem objects to be returned instead, then use the
  * secret_collection_search() and secret_collection_search_finish() functions.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full) (array zero-terminated=1): an array of DBus object
  *          paths for matching items.
  */
@@ -401,7 +412,7 @@ secret_collection_search_for_dbus_paths_finish (SecretCollection *collection,
 }
 
 /**
- * secret_collection_search_for_dbus_paths_sync:
+ * secret_collection_search_for_dbus_paths_sync: (skip)
  * @collection: the secret collection
  * @schema: (allow-none): the schema for the attributes
  * @attributes: (element-type utf8 utf8): search for items matching these attributes
@@ -419,6 +430,8 @@ secret_collection_search_for_dbus_paths_finish (SecretCollection *collection,
  * #SecretItem objects to be returned instead, then use the
  * secret_collection_search_sync() function.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full) (array zero-terminated=1): an array of DBus object
  *          paths for matching items.
  */
@@ -454,7 +467,7 @@ secret_collection_search_for_dbus_paths_sync (SecretCollection *collection,
 }
 
 /**
- * secret_service_search_for_dbus_paths:
+ * secret_service_search_for_dbus_paths: (skip)
  * @self: the secret service
  * @schema: (allow-none): the schema for the attributes
  * @attributes: (element-type utf8 utf8): search for items matching these attributes
@@ -472,6 +485,8 @@ secret_collection_search_for_dbus_paths_sync (SecretCollection *collection,
  * to get the results of this function. Only the D-Bus object paths of the
  * items will be returned. If you would like #SecretItem objects to be returned
  * instead, then use the secret_service_search() function.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_search_for_dbus_paths (SecretService *self,
@@ -523,7 +538,7 @@ _secret_service_search_for_paths_variant (SecretService *self,
 }
 
 /**
- * secret_service_search_for_dbus_paths_finish:
+ * secret_service_search_for_dbus_paths_finish: (skip)
  * @self: the secret service
  * @result: asynchronous result passed to callback
  * @unlocked: (out) (transfer full) (array zero-terminated=1) (allow-none):
@@ -545,6 +560,8 @@ _secret_service_search_for_paths_variant (SecretService *self,
  * instead, then us the secret_service_search() and
  * secret_service_search_finish() functions.
  *
+ * Stability: Unstable
+ *
  * Returns: whether the search was successful or not
  */
 gboolean
@@ -580,7 +597,7 @@ secret_service_search_for_dbus_paths_finish (SecretService *self,
 }
 
 /**
- * secret_service_search_for_dbus_paths_sync:
+ * secret_service_search_for_dbus_paths_sync: (skip)
  * @self: the secret service
  * @schema: (allow-none): the schema for the attributes
  * @attributes: (element-type utf8 utf8): search for items matching these attributes
@@ -607,6 +624,8 @@ secret_service_search_for_dbus_paths_finish (SecretService *self,
  * @locked arrays. If you would to have #SecretItem objects to be returned
  * instead, then use the secret_service_search_sync() function.
  *
+ * Stability: Unstable
+ *
  * Returns: whether the search was successful or not
  */
 gboolean
@@ -720,7 +739,7 @@ on_get_secrets_session (GObject *source,
 }
 
 /**
- * secret_service_get_secret_for_dbus_path:
+ * secret_service_get_secret_for_dbus_path: (skip)
  * @self: the secret service
  * @item_path: the D-Bus path to item to retrieve secret for
  * @cancellable: optional cancellation object
@@ -734,6 +753,8 @@ on_get_secrets_session (GObject *source,
  * get its secret value.
  *
  * This function returns immediately and completes asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_get_secret_for_dbus_path (SecretService *self,
@@ -765,7 +786,7 @@ secret_service_get_secret_for_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_get_secret_for_dbus_path_finish:
+ * secret_service_get_secret_for_dbus_path_finish: (skip)
  * @self: the secret service
  * @result: asynchronous result passed to callback
  * @error: location to place an error on failure
@@ -775,6 +796,8 @@ secret_service_get_secret_for_dbus_path (SecretService *self,
  *
  * Will return %NULL if the item is locked.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full) (allow-none): the newly allocated secret value
  *          for the item, which should be released with secret_value_unref()
  */
@@ -800,7 +823,7 @@ secret_service_get_secret_for_dbus_path_finish (SecretService *self,
 }
 
 /**
- * secret_service_get_secret_for_dbus_path_sync:
+ * secret_service_get_secret_for_dbus_path_sync: (skip)
  * @self: the secret service
  * @item_path: the D-Bus path to item to retrieve secret for
  * @cancellable: optional cancellation object
@@ -817,6 +840,8 @@ secret_service_get_secret_for_dbus_path_finish (SecretService *self,
  *
  * Will return %NULL if the item is locked.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full) (allow-none): the newly allocated secret value
  *          for the item, which should be released with secret_value_unref()
  */
@@ -851,7 +876,7 @@ secret_service_get_secret_for_dbus_path_sync (SecretService *self,
 }
 
 /**
- * secret_service_get_secrets_for_dbus_paths:
+ * secret_service_get_secrets_for_dbus_paths: (skip)
  * @self: the secret service
  * @item_paths: the D-Bus paths to items to retrieve secrets for
  * @cancellable: optional cancellation object
@@ -865,6 +890,8 @@ secret_service_get_secret_for_dbus_path_sync (SecretService *self,
  * get their secret values.
  *
  * This function returns immediately and completes asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_get_secrets_for_dbus_paths (SecretService *self,
@@ -896,7 +923,7 @@ secret_service_get_secrets_for_dbus_paths (SecretService *self,
 }
 
 /**
- * secret_service_get_secrets_for_dbus_paths_finish:
+ * secret_service_get_secrets_for_dbus_paths_finish: (skip)
  * @self: the secret service
  * @result: asynchronous result passed to callback
  * @error: location to place an error on failure
@@ -906,7 +933,9 @@ secret_service_get_secrets_for_dbus_paths (SecretService *self,
  *
  * Items that are locked will not be included the results.
  *
- * Returns: (transfer full) (element-type utf8 SecretUnstable.Value): a newly
+ * Stability: Unstable
+ *
+ * Returns: (transfer full) (element-type utf8 Secret.Value): a newly
  *          allocated hash table of item_path keys to #SecretValue
  *          values.
  */
@@ -932,7 +961,7 @@ secret_service_get_secrets_for_dbus_paths_finish (SecretService *self,
 }
 
 /**
- * secret_service_get_secrets_for_dbus_paths_sync:
+ * secret_service_get_secrets_for_dbus_paths_sync: (skip)
  * @self: the secret service
  * @item_paths: the D-Bus paths to items to retrieve secrets for
  * @cancellable: optional cancellation object
@@ -949,7 +978,9 @@ secret_service_get_secrets_for_dbus_paths_finish (SecretService *self,
  *
  * Items that are locked will not be included the results.
  *
- * Returns: (transfer full) (element-type utf8 SecretUnstable.Value): a newly
+ * Stability: Unstable
+ *
+ * Returns: (transfer full) (element-type utf8 Secret.Value): a newly
  *          allocated hash table of item_path keys to #SecretValue
  *          values.
  */
@@ -1123,7 +1154,7 @@ _secret_service_xlock_paths_finish (SecretService *self,
 }
 
 /**
- * secret_service_lock_dbus_paths_sync:
+ * secret_service_lock_dbus_paths_sync: (skip)
  * @self: the secret service
  * @paths: the D-Bus object paths of the items or collections to lock
  * @cancellable: optional cancellation object
@@ -1145,6 +1176,8 @@ _secret_service_xlock_paths_finish (SecretService *self,
  * interface threads. The secret service may prompt the user.
  * secret_service_prompt() will be used to handle any prompts that show up.
  *
+ * Stability: Unstable
+ *
  * Returns: the number of items or collections that were locked
  */
 gint
@@ -1180,7 +1213,7 @@ secret_service_lock_dbus_paths_sync (SecretService *self,
 }
 
 /**
- * secret_service_lock_dbus_paths:
+ * secret_service_lock_dbus_paths: (skip)
  * @self: the secret service
  * @paths: the D-Bus paths for items or collections to lock
  * @cancellable: optional cancellation object
@@ -1199,6 +1232,8 @@ secret_service_lock_dbus_paths_sync (SecretService *self,
  * This method returns immediately and completes asynchronously. The secret
  * service may prompt the user. secret_service_prompt() will be used to handle
  * any prompts that show up.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_lock_dbus_paths (SecretService *self,
@@ -1216,7 +1251,7 @@ secret_service_lock_dbus_paths (SecretService *self,
 }
 
 /**
- * secret_service_lock_dbus_paths_finish:
+ * secret_service_lock_dbus_paths_finish: (skip)
  * @self: the secret service
  * @result: asynchronous result passed to the callback
  * @locked: (out) (array zero-terminated=1) (transfer full) (allow-none):
@@ -1230,6 +1265,8 @@ secret_service_lock_dbus_paths (SecretService *self,
  * The secret service may not be able to lock items individually, and may
  * lock an entire collection instead.
  *
+ * Stability: Unstable
+ *
  * Returns: the number of items or collections that were locked
  */
 gint
@@ -1246,7 +1283,7 @@ secret_service_lock_dbus_paths_finish (SecretService *self,
 }
 
 /**
- * secret_service_unlock_dbus_paths_sync:
+ * secret_service_unlock_dbus_paths_sync: (skip)
  * @self: the secret service
  * @paths: the D-Bus object paths of the items or collections to unlock
  * @cancellable: optional cancellation object
@@ -1268,6 +1305,8 @@ secret_service_lock_dbus_paths_finish (SecretService *self,
  * interface threads. The secret service may prompt the user.
  * secret_service_prompt() will be used to handle any prompts that show up.
  *
+ * Stability: Unstable
+ *
  * Returns: the number of items or collections that were unlocked
  */
 gint
@@ -1303,7 +1342,7 @@ secret_service_unlock_dbus_paths_sync (SecretService *self,
 }
 
 /**
- * secret_service_unlock_dbus_paths:
+ * secret_service_unlock_dbus_paths: (skip)
  * @self: the secret service
  * @paths: the D-Bus paths for items or collections to unlock
  * @cancellable: optional cancellation object
@@ -1322,6 +1361,8 @@ secret_service_unlock_dbus_paths_sync (SecretService *self,
  * This method returns immediately and completes asynchronously. The secret
  * service may prompt the user. secret_service_prompt() will be used to handle
  * any prompts that show up.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_unlock_dbus_paths (SecretService *self,
@@ -1340,7 +1381,7 @@ secret_service_unlock_dbus_paths (SecretService *self,
 }
 
 /**
- * secret_service_unlock_dbus_paths_finish:
+ * secret_service_unlock_dbus_paths_finish: (skip)
  * @self: the secret service
  * @result: asynchronous result passed to the callback
  * @unlocked: (out) (array zero-terminated=1) (transfer full) (allow-none):
@@ -1354,6 +1395,8 @@ secret_service_unlock_dbus_paths (SecretService *self,
  * The secret service may not be able to unlock items individually, and may
  * unlock an entire collection instead.
  *
+ * Stability: Unstable
+ *
  * Returns: the number of items or collections that were unlocked
  */
 gint
@@ -1500,7 +1543,7 @@ _secret_service_delete_path_finish (SecretService *self,
 }
 
 /**
- * secret_service_delete_item_dbus_path:
+ * secret_service_delete_item_dbus_path: (skip)
  * @self: the secret service
  * @item_path: the D-Bus path of item to delete
  * @cancellable: optional cancellation object
@@ -1513,6 +1556,8 @@ _secret_service_delete_path_finish (SecretService *self,
  * #SecretItem proxy objects, use use secret_item_delete() instead.
  *
  * This method will return immediately and complete asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_delete_item_dbus_path (SecretService *self,
@@ -1529,7 +1574,7 @@ secret_service_delete_item_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_delete_item_dbus_path_finish:
+ * secret_service_delete_item_dbus_path_finish: (skip)
  * @self: the secret service
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
@@ -1537,6 +1582,8 @@ secret_service_delete_item_dbus_path (SecretService *self,
  * Complete an asynchronous operation to delete a secret item from the secret
  * service.
  *
+ * Stability: Unstable
+ *
  * Returns: whether the deletion was successful or not
  */
 gboolean
@@ -1553,7 +1600,7 @@ secret_service_delete_item_dbus_path_finish (SecretService *self,
 }
 
 /**
- * secret_service_delete_item_dbus_path_sync:
+ * secret_service_delete_item_dbus_path_sync: (skip)
  * @self: the secret service
  * @item_path: the D-Bus path of item to delete
  * @cancellable: optional cancellation object
@@ -1567,6 +1614,8 @@ secret_service_delete_item_dbus_path_finish (SecretService *self,
  * This method may block indefinitely and should not be used in user interface
  * threads.
  *
+ * Stability: Unstable
+ *
  * Returns: whether the deletion was successful or not
  */
 gboolean
@@ -1675,7 +1724,7 @@ on_create_collection_called (GObject *source,
 }
 
 /**
- * secret_service_create_collection_dbus_path:
+ * secret_service_create_collection_dbus_path: (skip)
  * @self: a secret service object
  * @properties: (element-type utf8 GLib.Variant): hash table of properties for
  *              the new collection
@@ -1709,6 +1758,8 @@ on_create_collection_called (GObject *source,
  * This method will return immediately and complete asynchronously. The secret
  * service may prompt the user. secret_service_prompt() will be used to handle
  * any prompts that are required.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_create_collection_dbus_path (SecretService *self,
@@ -1757,7 +1808,7 @@ secret_service_create_collection_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_create_collection_dbus_path_finish:
+ * secret_service_create_collection_dbus_path_finish: (skip)
  * @self: a secret service object
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
@@ -1765,6 +1816,8 @@ secret_service_create_collection_dbus_path (SecretService *self,
  * Finish asynchronous operation to create a new collection in the secret
  * service.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): a new string containing the D-Bus object path
  *          of the collection
  */
@@ -1793,7 +1846,7 @@ secret_service_create_collection_dbus_path_finish (SecretService *self,
 }
 
 /**
- * secret_service_create_collection_dbus_path_sync:
+ * secret_service_create_collection_dbus_path_sync: (skip)
  * @self: a secret service object
  * @properties: (element-type utf8 GLib.Variant): hash table of D-Bus properties
  *              for the new collection
@@ -1825,6 +1878,8 @@ secret_service_create_collection_dbus_path_finish (SecretService *self,
  * threads. The secret service may prompt the user. secret_service_prompt()
  * will be used to handle any prompts that are required.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): a new string containing the D-Bus object path
  *          of the collection
  */
@@ -1982,7 +2037,7 @@ on_create_item_session (GObject *source,
 }
 
 /**
- * secret_service_create_item_dbus_path:
+ * secret_service_create_item_dbus_path: (skip)
  * @self: a secret service object
  * @collection_path: the D-Bus object path of the collection in which to create item
  * @properties: (element-type utf8 GLib.Variant): hash table of D-Bus properties
@@ -2012,6 +2067,8 @@ on_create_item_session (GObject *source,
  * This method will return immediately and complete asynchronously. The secret
  * service may prompt the user. secret_service_prompt() will be used to handle
  * any prompts that are required.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_create_item_dbus_path (SecretService *self,
@@ -2051,7 +2108,7 @@ secret_service_create_item_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_create_item_dbus_path_finish:
+ * secret_service_create_item_dbus_path_finish: (skip)
  * @self: a secret service object
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
@@ -2059,6 +2116,8 @@ secret_service_create_item_dbus_path (SecretService *self,
  * Finish asynchronous operation to create a new item in the secret
  * service.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): a new string containing the D-Bus object path
  *          of the item
  */
@@ -2124,6 +2183,8 @@ _secret_service_create_item_dbus_path_finish_raw (GAsyncResult *result,
  * threads. The secret service may prompt the user. secret_service_prompt()
  * will be used to handle any prompts that are required.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): a new string containing the D-Bus object path
  *          of the item
  */
@@ -2162,7 +2223,7 @@ secret_service_create_item_dbus_path_sync (SecretService *self,
 }
 
 /**
- * secret_service_read_alias_dbus_path:
+ * secret_service_read_alias_dbus_path: (skip)
  * @self: a secret service object
  * @alias: the alias to lookup
  * @cancellable: (allow-none): optional cancellation object
@@ -2174,6 +2235,8 @@ secret_service_create_item_dbus_path_sync (SecretService *self,
  * dbus object path of the well known collection.
  *
  * This method will return immediately and complete asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_read_alias_dbus_path (SecretService *self,
@@ -2193,7 +2256,7 @@ secret_service_read_alias_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_read_alias_dbus_path_finish:
+ * secret_service_read_alias_dbus_path_finish: (skip)
  * @self: a secret service object
  * @result: asynchronous result passed to callback
  * @error: location to place error on failure
@@ -2201,6 +2264,8 @@ secret_service_read_alias_dbus_path (SecretService *self,
  * Finish an asynchronous operation to lookup which collection is assigned
  * to an alias. This method returns the DBus object path of the collection
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): the collection dbus object path, or %NULL if
  *          none assigned to the alias
  */
@@ -2230,7 +2295,7 @@ secret_service_read_alias_dbus_path_finish (SecretService *self,
 }
 
 /**
- * secret_service_read_alias_dbus_path_sync:
+ * secret_service_read_alias_dbus_path_sync: (skip)
  * @self: a secret service object
  * @alias: the alias to lookup
  * @cancellable: (allow-none): optional cancellation object
@@ -2242,6 +2307,8 @@ secret_service_read_alias_dbus_path_finish (SecretService *self,
  *
  * This method may block and should not be used in user interface threads.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): the collection dbus object path, or %NULL if
  *          none assigned to the alias
  */
@@ -2275,7 +2342,7 @@ secret_service_read_alias_dbus_path_sync (SecretService *self,
 }
 
 /**
- * secret_service_set_alias_to_dbus_path:
+ * secret_service_set_alias_to_dbus_path: (skip)
  * @self: a secret service object
  * @alias: the alias to assign the collection to
  * @collection_path: (allow-none): the dbus object path of the collection to assign to the alias
@@ -2288,6 +2355,8 @@ secret_service_read_alias_dbus_path_sync (SecretService *self,
  * path of the collection to assign to the alias.
  *
  * This method will return immediately and complete asynchronously.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_set_alias_to_dbus_path (SecretService *self,
@@ -2313,13 +2382,15 @@ secret_service_set_alias_to_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_set_alias_to_dbus_path_finish:
+ * secret_service_set_alias_to_dbus_path_finish: (skip)
  * @self: a secret service object
  * @result: asynchronous result passed to callback
  * @error: location to place error on failure
  *
  * Finish an asynchronous operation to assign a collection to an alias.
  *
+ * Stability: Unstable
+ *
  * Returns: %TRUE if successful
  */
 gboolean
@@ -2343,7 +2414,7 @@ secret_service_set_alias_to_dbus_path_finish (SecretService *self,
 }
 
 /**
- * secret_service_set_alias_to_dbus_path_sync:
+ * secret_service_set_alias_to_dbus_path_sync: (skip)
  * @self: a secret service object
  * @alias: the alias to assign the collection to
  * @collection_path: (allow-none): the dbus object path of the collection to assign to the alias
@@ -2356,6 +2427,8 @@ secret_service_set_alias_to_dbus_path_finish (SecretService *self,
  *
  * This method may block and should not be used in user interface threads.
  *
+ * Stability: Unstable
+ *
  * Returns: %TRUE if successful
  */
 gboolean
@@ -2394,6 +2467,31 @@ secret_service_set_alias_to_dbus_path_sync (SecretService *self,
 	return ret;
 }
 
+/**
+ * secret_service_prompt_at_dbus_path_sync: (skip)
+ * @self: the secret service
+ * @prompt_path: the D-Bus object path of the prompt
+ * @cancellable: optional cancellation object
+ * @return_type: (allow-none): the variant type of the prompt result
+ * @error: location to place error on failure
+ *
+ * Perform prompting for a #SecretPrompt.
+ *
+ * Override the #SecretServiceClass <literal>prompt_async</literal> virtual method
+ * to change the behavior of the propmting. The default behavior is to simply
+ * run secret_prompt_perform() on the prompt.
+ *
+ * Returns a variant result if the prompt was completed and not dismissed. The
+ * type of result depends on the action the prompt is completing, and is defined
+ * in the Secret Service DBus API specification.
+ *
+ * This method may block and should not be used in user interface threads.
+ *
+ * Stability: Unstable
+ *
+ * Returns: (transfer full): %NULL if the prompt was dismissed or an error occurred,
+ *          a variant result if the prompt was successful
+ */
 GVariant *
 secret_service_prompt_at_dbus_path_sync (SecretService *self,
                                          const gchar *prompt_path,
@@ -2417,7 +2515,7 @@ secret_service_prompt_at_dbus_path_sync (SecretService *self,
 }
 
 /**
- * secret_service_prompt_at_dbus_path:
+ * secret_service_prompt_at_dbus_path: (skip)
  * @self: the secret service
  * @prompt_path: the D-Bus object path of the prompt
  * @return_type: (allow-none): the variant type of the prompt result
@@ -2433,6 +2531,8 @@ secret_service_prompt_at_dbus_path_sync (SecretService *self,
  * Override the #SecretServiceClass <literal>prompt_async</literal> virtual method
  * to change the behavior of the propmting. The default behavior is to simply
  * run secret_prompt_perform() on the prompt.
+ *
+ * Stability: Unstable
  */
 void
 secret_service_prompt_at_dbus_path (SecretService *self,
@@ -2454,7 +2554,7 @@ secret_service_prompt_at_dbus_path (SecretService *self,
 }
 
 /**
- * secret_service_prompt_at_dbus_path_finish:
+ * secret_service_prompt_at_dbus_path_finish: (skip)
  * @self: the secret service
  * @result: the asynchronous result passed to the callback
  * @error: location to place an error on failure
@@ -2465,6 +2565,8 @@ secret_service_prompt_at_dbus_path (SecretService *self,
  * type of result depends on the action the prompt is completing, and is defined
  * in the Secret Service DBus API specification.
  *
+ * Stability: Unstable
+ *
  * Returns: (transfer full): %NULL if the prompt was dismissed or an error occurred,
  *          a variant result if the prompt was successful
  */
@@ -2479,3 +2581,62 @@ secret_service_prompt_at_dbus_path_finish (SecretService *self,
 
 	return secret_service_prompt_finish (self, result, error);
 }
+
+/**
+ * secret_service_encode_dbus_secret:
+ * @service: the service
+ * @value: the secret value
+ *
+ * Encodes a #SecretValue into GVariant for use with the Secret Service
+ * DBus API.
+ *
+ * The resulting GVariant will have a <literal>(oayays)</literal> signature.
+ *
+ * A session must have already been established by the #SecretService.
+ *
+ * Returns: (transfer floating): the encoded secret
+ */
+GVariant *
+secret_service_encode_dbus_secret (SecretService *service,
+                                   SecretValue *value)
+{
+	SecretSession *session;
+
+	g_return_val_if_fail (service != NULL, NULL);
+	g_return_val_if_fail (value != NULL, NULL);
+
+	session = _secret_service_get_session (service);
+	g_return_val_if_fail (session != NULL, NULL);
+
+	return _secret_session_encode_secret (session, value);
+}
+
+/**
+ * secret_service_decode_dbus_secret:
+ * @service: the service
+ * @value: the encoded secret
+ *
+ * Decode a #SecretValue into GVariant received with the Secret Service
+ * DBus API.
+ *
+ * The GVariant should have a <literal>(oayays)</literal> signature.
+ *
+ * A session must have already been established by the #SecretService, and
+ * the encoded secret must be valid for that session.
+ *
+ * Returns: (transfer full): the decoded secret value
+ */
+SecretValue *
+secret_service_decode_dbus_secret (SecretService *service,
+                                   GVariant *value)
+{
+	SecretSession *session;
+
+	g_return_val_if_fail (service != NULL, NULL);
+	g_return_val_if_fail (value != NULL, NULL);
+
+	session = _secret_service_get_session (service);
+	g_return_val_if_fail (session != NULL, NULL);
+
+	return _secret_session_decode_secret (session, value);
+}
